@@ -27,7 +27,7 @@
 ColorPicker::ColorPicker(QWidget* parent)
 	: QDialog(parent)
 {
-	setWindowTitle(i18n("Color Picker"));
+	setWindowTitle(i18nc("@title:window", "Color Picker"));
 	setModal(false);
 
 	QVBoxLayout *mainLayout = new QVBoxLayout;
@@ -162,5 +162,5 @@ void ColorPicker::copyProxy()
 
 void ColorPicker::pasteProxy()
 {
-	emit pasteText(resultBox->text());
+	Q_EMIT pasteText(resultBox->text());
 }
