@@ -28,7 +28,7 @@ class ColorPatch : public QFrame
         void setColor(const QColor &c) { col = c; }
 
 	protected:
-		void paintEvent(QPaintEvent *e) Q_DECL_OVERRIDE {
+		void paintEvent(QPaintEvent *e) override {
 			QPainter p(this);
 			drawFrame(&p);
 			p.fillRect(contentsRect()&e->rect(), col);
@@ -48,10 +48,10 @@ class ColorPicker : public QDialog
 	public:
         explicit ColorPicker(QWidget* parent = nullptr);
 
-	signals:
+	Q_SIGNALS:
 		void pasteText(const QString&);
 
-	private slots:
+	private Q_SLOTS:
 		void updateResult(int r, int g, int b);
 		void redChanged(int);
 		void greenChanged(int);
